==> dogtag-pki_11.0.0.orig.tar.xz: pki-11.0.0/base/console/src/main/java/com/netscape/admin/certsrv/managecert/ManageCertModel.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2007 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.admin.certsrv.managecert;

import com.netscape.admin.certsrv.*;

/**
 * Manage certificate data model - represents the instance
 * table information
 *
 * @author Christine Ho
 * @version $Revision$, $Date$
 */
public class ManageCertModel extends CMSTableModel
{

    /*==========================================================
     * variables
     *==========================================================*/
    public static final String COL1 = "CERTNAME";
    public static final String COL2 = "EXPIRED";
    public static final String COL3 = "TRUST";

    private static String[] mColumns = {COL1, COL2, COL3};

    /*==========================================================
     * constructors
     *==========================================================*/
    public ManageCertModel() {
        super();
        init(mColumns);
    }

    @Override
    public boolean isCellEditable(int row, int col) {
        return false;
    }
}

==> dogtag-pki_11.2.1.orig.tar.xz: pki-11.2.1/base/console/src/main/java/com/netscape/admin/certsrv/managecert/ManageCertModel.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2007 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.admin.certsrv.managecert;

import com.netscape.admin.certsrv.CMSTableModel;

/**
 * Manage certificate data model - represents the instance
 * table information
 *
 * @author Christine Ho
 * @version $Revision$, $Date$
 * @deprecated The PKI console will be removed once there are CLI equivalents of desired console features.
 */
@Deprecated(since="10.14.0", forRemoval=true)
public class ManageCertModel extends CMSTableModel
{

    /*==========================================================
     * variables
     *==========================================================*/
    public static final String COL1 = "CERTNAME";
    public static final String COL2 = "EXPIRED";
    public static final String COL3 = "TRUST";

    private static String[] mColumns = {COL1, COL2, COL3};

    /*==========================================================
     * constructors
     *==========================================================*/
    public ManageCertModel() {
        super();
        init(mColumns);
    }

    @Override
    public boolean isCellEditable(int row, int col) {
        return false;
    }
}
